# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.9.0] - 2023-06-16

## Changed

- The variable `REPREPBUILD_CASE_FMT` is no longer prefixed with the script name
  to create filenames for log and dependency files.
  Instead, it is used as such, without prefixing anything to it.
- A plain `dataset` directory is now also recognized and turned into a ZIP file.

## [0.8.0] - 2023-05-26

### Fixed

- Added sanity check to `rrr` command.

### Changed

- Optional customization of formatting and parsing of script arguments when using
  `reprepbuild_cases`.

## [0.7.4] - 2023-05-15

### Fixed

- Make local imports of Python scripts work when executed through RepRepBuild.

## [0.7.3] - 2023-05-10

### Fixed

- Also detect bare `results` folder without suffix.

## [0.7.2] - 2023-04-27

### Fixed

- Support for upper case in Python scripts and SVG files.
- Ignore Python scripts that cannot be imported.
  When this happens, a comment is added to `build.ninja`.

## [0.7.1] - 2023-04-19

### Fixed

- Enfore a different extension than `.tex` for autogenerated LaTeX sources
  to break circular dependencies.
- Fix mistakes in depfile for Python scripts.

## [0.7.0] - 2023-04-17

### Fixed

- Add option to latexdiff to track changes in other common sections in articles.

### Changed

- Also ZIP the supporting information sources, which is needed in some scenario's,
  such as submission of a preprint to arXiv.

## [0.6.0] - 2023-04-12

### Fixed

- Add option to latexdiff to track changes in the abstract when it is in the preamble.

### Changed

- Run bibsane directly after bibtex, using the configuration file `bibsane.yaml` located
  next to the `build.ninja` file.

## [0.5.1] - 2023-04-11

### Fixed

- Get latexdiff to work.

## [0.5.0] - 2023-03-30

### Fixed

- Use regular deflation algorithm for a more acceptable ZIP compression time.
- Allow for more filename patterns when assigning build rules.

### Changed

- When the compression of the ZIP file takes more than 1 second, a progress bar appears.
  This introduces a dependency on [`tqdm`](https://github.com/tqdm/tqdm).

## [0.4.2] - 2023-03-25

### Fixed

- Fix typo in `rr-bibtex` script.

## [0.4.1] - 2023-03-25

### Fixed

- Add missing depfile lines to `latexdep` and `bibtex` build rules.
- Let the build fail when `bibtex` finds no `.bib` file.

## [0.4.0] - 2023-03-24

### Changed

- The LaTeX sources no longer built without `latexmk`.
  It is replaced by a set of build commands in the `build.ninja` file generated by rr.
  A few extra scripts were added to make this all work: `rr-latexdep` and `rr-bibtex`.
- When LaTeX makes an emergency stop, which is not compatible with RepRepBuild,
  `rr-latexdep` will explain how to solve this problem.

### Fixed

- Fixed compression of ZIP files.
- The regular expression has been updated to be more permissive and now matches Python files with numbers in their name.
- Fix minor typos and update the regular expression for function arguments to allow for strings containing both letters and numbers to be valid function arguments.

## [0.3.1] - 2023-03-21

### Fixed

- Discard existing intermediates when recompiling LaTeX source.

## [0.3.0] - 2023-03-21

### Changed

- `rr` implemenetation
  - Many cleanups in `__main__` (simpler and safer code, more reuse)
- Improvements to `rr-python-script`
  - Parallel executions of parameterized scripts.
  - Logging of script output, compatible with pytest.
  - Allow underscores in script names.
- Improvements to `rr-latex`: improved output and code cleanups.
- Minor cleanups after linting

### Fixed

- Add BibTeX files to the dynamic dependencies.
- Allow (and require) configuration of `latexmk` through `latexmkrc`.
- Fix printing of relevant part of pdflatex log.
- Load LaTeX log file as binary, because its encoding is unpredictable.
- Sort files inside ZIP to make their order reproducible.

## [0.2.0] - 2023-03-16

### Fixed

- Fixed other minor dependency tracking issues
- Fixed dependency issues for Latex files.
- Assume `SOURCE_DATE_EPOCH=315532800` (Jan 1, 1980) for compatibility with ZIP files.
- When writing a build.ninja file, change directory before importing a python script.

### Changed

- Alpha status
- Aim for Python 3.6
- All command-line arguments of `rr` and `rrr` are given to the `ninja` subprocess.

## [0.1.2] - 2023-03-15

### Added

- The main build command `rr` and its continuous equivalent `rrr`.
- Utilities that users do not need to interact with directly.
  (They are invoked by `rr` when appropriate.)
  - `rr-zip`: Create a reproducible zip file (timestamps fixed at 1980-01-01T00:00:00Z)
  - `rr-article-zip`: Create a reproducible zip file with all LaTeX inputs of an article.
  - `rr-latex`: Compile a reproducible PDF with LaTeX, including dependency tracking
  - `rr-python-script`: Execute a Python script, including dependency tracking.
  - `rr-normalize-pdf`: Remove irrelevant metadata and standardize a PDF file.
